<?php

namespace Jiwei\EasyHttpSdk\Policy;

use Jiwei\EasyHttpSdk\Exception\GuiltyResultException;
use Jiwei\EasyHttpSdk\Exception\UnknowResultException;
use Psr\Http\Message\ResponseInterface;

class DefaultErrorHandlingPolicy implements HandlingPolicyInterface
{
    /**
     * @param ResponseInterface $response
     * @return array<string, mixed>
     */
    public function process(ResponseInterface $response): array
    {
        if ($response->getStatusCode() == 304) {
            return [];
        }

        $responseInfo = $response->getBody()->getContents();
        $rpcResult = json_decode($responseInfo, true);

        if (json_last_error()) {
            throw new UnknowResultException("Content Format error.", $responseInfo);
        }

        if (!empty($rpcResult['name']) && $response->getStatusCode() >= 400) {
            $errorMessage = sprintf("%s : %s", $rpcResult['name'], $rpcResult['message'] ?? "");
            throw new GuiltyResultException($errorMessage, $rpcResult);
        }
        return $rpcResult;
    }
}
